@@ -20,16 +20,22 @@ if 'test' in os.listdir('.'):
 
 class TestXlsxReaderOutput(unittest.TestCase):
     
-    def test_file_path_output(self):
-        self.maxDiff = None
+    def test_path_dates_styles_output(self):
         with open('./testbook1.csv', encoding='utf-8-sig') as file:
             correct_out = file.read()
-        #print(correct_out)
-        #for i in range(10): print("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n")
         test_file = readxlsx('./testbook1.xlsx')
         test_file.seek(0)
         test_out = str(test_file.read(), encoding='utf-8')
-        #print(test_out)
+        self.assertEqual(correct_out, test_out)
+
+    def test_path_large_input_output(self):
+        with open('./testbook2.csv', encoding='utf-8-sig') as file:
+            correct_out = file.read()
+        test_file = readxlsx('./testbook2.xlsx')
+        test_file.seek(0)
+        test_out = str(test_file.read(), encoding='utf-8')
+        with open('test.txt', 'w') as file:
+            file.write(test_out)
         self.assertEqual(correct_out, test_out)
 
 if __name__ == '__main__':
