@@ -1,6 +1,6 @@
-
 import zipfile
 import sys
+import os
 import shutil
 from xml.etree import cElementTree as ET
 import time
@@ -56,17 +56,18 @@ else:
 
 
 def readxlsx(file_name,worksheet_to_read_index=1, return_file_name='unamed',return_file_suffix='.csv', return_file_delete=False,delimiter=',',quote_char='"',end_of_record='\n'):
-    """Reads an .xlsx file and returns a python tempfile"""
-    #try:
+    """Reads an .xlsx file and returns a python tempfile
+    
+    """
+    file_name = check_file(file_name)
+    
     if True: 
         with zipfile.ZipFile(file_name) as f_zip:
 
             worksheets = load_workbook(f_zip)
             shared_strings = get_sharedStrings(f_zip)
             styles = get_styles(f_zip)
-            temp_file = temp_file = tempfile.NamedTemporaryFile(
-                prefix=return_file_name, suffix=return_file_suffix, delete=return_file_delete
-            )
+            temp_file = temp_file = tempfile.NamedTemporaryFile(prefix=return_file_name, suffix=return_file_suffix, delete=return_file_delete)
             data = scrape(f_zip, worksheets[worksheet_to_read_index]["sheet_path"], shared_strings, styles)
     #except:
     #    return None
@@ -88,6 +89,32 @@ def readxlsx(file_name,worksheet_to_read_index=1, return_file_name='unamed',retu
 
     return temp_file
 
+def check_file(file_name):
+    #best check I could come up withif a InMemoryUploadedFile
+    if str(type(file_name)) == "<class 'django.core.files.uploadedfile.InMemoryUploadedFile'>":
+        return file_name
+
+    elif 'pathlib' in str(type(file_name)): 
+        file_name = str(file_name)
+
+    elif 'path' in dir(file_name):
+        file_name = file_name.path
+
+    elif 'name' in dir(file_name):
+        io_file_name = os.path.split(file_name)[-1]
+        with open('.temp_' + io_file_name, 'wb') as file:
+            file.write(file_name.read())
+        file_name = '.temp_' + io_file_name
+
+    if type(file_name) is not str:
+        raise UserWarning('Not a file path string ({}).'.format(file_name))
+    if not os.path.isfile(file_name):
+        raise UserWarning('File ({}) does not exist.'.format(file_name))
+    if file_name.split('.')[-1] != 'xlsx':
+        raise UserWarning('Must be a .xlsx file')
+    
+    return file_name
+
 def load_workbook(f_zip):
 
     worksheets = {}
@@ -192,7 +219,7 @@ def scrape(f_zip, worksheet_path, shared_strings, styles):
                     partialday = float(value) % 1
                     value = str(EXCEL_STARTDATE + timedelta(days=int(value.split('.')[0]), seconds=partialday * 86400))
                 else:
-                    value = str(value)
+                    value = str(float(value))
 
         if address[0] > max_address[0]:
             max_address = (address[0], max_address[1])
@@ -259,4 +286,4 @@ def column_to_num(column_name):
     except IndexError:
         return val
 
-    return val
+    return val
\ No newline at end of file
